MeshValidationError

Enum MeshValidationError 

#[non_exhaustive]
pub enum MeshValidationError { IncompleteTriangle { index_count: usize, }, PositionIndexOutOfRange { index: u32, position_count: usize, }, NormalCount { expected: usize, actual: usize, }, NormalIndexCount { expected: usize, actual: usize, }, NormalIndexOutOfRange { index: u32, normal_count: usize, }, AttributeCount { name: String, expected: usize, actual: usize, }, AttributeZeroWidth { name: String, }, AttributeDuplicateName { name: String, }, AttributeRaggedValues { name: String, values: usize, width: usize, }, AttributeCornerCount { name: String, expected: usize, actual: usize, }, AttributeCornerIndexOutOfRange { name: String, index: u32, value_count: usize, }, AttributePartiallyMapped { name: String, triangle: usize, }, }
Cheap structural validation failure.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


IncompleteTriangle

Triangle index buffer is not divisible by three.

Fields

index_count: usize


PositionIndexOutOfRange

Position index does not exist.

Fields

index: u32
position_count: usize


NormalCount

Non-indexed normals do not align with positions.

Fields

expected: usize
actual: usize


NormalIndexCount

Independently indexed normals do not align with corners.

Fields

expected: usize
actual: usize


NormalIndexOutOfRange

Normal index does not exist.

Fields

index: u32
normal_count: usize


AttributeCount

A channel does not carry one tuple per vertex.

Fields

name: String

Channel name.

expected: usize

Vertices in the mesh.

actual: usize

Vertices the channel covers.



AttributeZeroWidth

A channel declares a zero tuple width, which covers no vertices.

Fields

name: String

Channel name.



AttributeDuplicateName

Two channels share a name, so a lookup would be ambiguous.

Fields

name: String

The repeated name.



AttributeRaggedValues

A corner-indexed channel’s values is not whole tuples.

Fields

name: String

Channel name.

values: usize

Scalars found.

width: usize

Declared tuple width.



AttributeCornerCount

A corner-indexed channel does not have one entry per triangle corner.

Fields

name: String

Channel name.

expected: usize

Triangle corners in the mesh.

actual: usize

Corner entries in the channel.



AttributeCornerIndexOutOfRange

A corner index points past the channel’s values.

Fields

name: String

Channel name.

index: u32

The offending index.

value_count: usize

Tuples available.



AttributePartiallyMapped

A triangle has some corners mapped and some unmapped.

Fields

name: String

Channel name.

triangle: usize

The triangle.